@@ -28,6 +28,7 @@ class Consumer(Base):
         super().__init__(connection, username, passcode)
         self.callback = lambda p: p
         self.destination = None
+        self.queue_name = None
         self.is_stopped = False
         self.subscribe_id = None
         self.set_listener(f"consumer-listener-{get_uuid()}", self.listener_class(self))
@@ -48,18 +49,20 @@ class Consumer(Base):
                 logger.exception(exc)
             else:
                 received.status = StatusChoice.SUCCEEDED
+                payload.ack()
             finally:
                 received.save()
         else:
             payload.ack()
 
-    def start(self, callback, destination):
+    def start(self, callback, destination, queue_name=None):
         if not self.is_stopped:
             self.connect()
             self.callback = callback
             self.destination = destination
-            self._create_dlq_queue(destination, self.subscribe_headers)
-            self._create_queue(destination, self.subscribe_headers)
+            self.queue_name = queue_name
+            self._create_dlq_queue(destination, self.subscribe_headers, queue_name)
+            self._create_queue(destination, self.subscribe_headers, queue_name)
             logger.info("Consumer started with id: %s", self.subscribe_id)
 
     def stop(self):
@@ -70,33 +73,35 @@ class Consumer(Base):
         else:
             logger.info("Consumer not started")
 
-    def _create_dlq_queue(self, destination, headers):
+    def _create_dlq_queue(self, destination, headers, queue_name=None):
         if not self.subscribe_id:
             subscribe_id = get_uuid()
-            self._subscribe(destination, subscribe_id, headers, dlq=True)
+            self._subscribe(destination, subscribe_id, headers, queue_name, dlq=True)
             self.connection.unsubscribe(subscribe_id)
 
-    def _create_queue(self, destination, headers):
+    def _create_queue(self, destination, headers, queue_name=None):
         if self.subscribe_id is None:
             self.subscribe_id = get_uuid()
-        self._subscribe(destination, self.subscribe_id, headers)
+        self._subscribe(destination, self.subscribe_id, headers, queue_name)
 
-    def _subscribe(self, destination, subscribe_id, headers, dlq=False):
+    def _subscribe(self, destination, subscribe_id, headers, queue_name=None, dlq=False):
+        # pylint: disable=too-many-arguments
         routing_key = destination.split("/")[-1]
+        queue_name = queue_name if queue_name else routing_key
         if dlq:
-            routing_key = f"DLQ.{routing_key}"
+            queue_name = f"DLQ.{queue_name}"
         headers.update(
             {
-                "x-queue-name": routing_key,
-                "x-dead-letter-routing-key": f"DLQ.DLQ.{routing_key}" if dlq else f"DLQ.{routing_key}",
+                "x-queue-name": queue_name,
+                "x-dead-letter-routing-key": f"DLQ.DLQ.{queue_name}" if dlq else f"DLQ.{queue_name}",
                 "x-dead-letter-exchange": "",
             }
         )
         if dlq:
-            self.connection.subscribe(routing_key, subscribe_id, ack="client", headers=headers)
+            self.connection.subscribe(queue_name, subscribe_id, ack="client", headers=headers)
         else:
             self.connection.subscribe(destination, subscribe_id, ack="client", headers=headers)
-        logger.info("Created queue %s with id: %s", routing_key, subscribe_id)
+        logger.info("Created queue %s with id: %s", queue_name, subscribe_id)
 
     def _unsubscribe(self):
         self.connection.unsubscribe(self.subscribe_id)
